@@ -4,6 +4,11 @@ from bale import (Message, CallbackQuery)
 if TYPE_CHECKING:
     from bale import Bot
 
+__all__ = (
+    "UpdateType",
+    "Update"
+)
+
 
 class UpdateType:
     """This object indicates an Update Type.
@@ -25,6 +30,10 @@ class UpdateType:
     def __init__(self, _type: str):
         self._type = _type
 
+    @property
+    def type(self) -> str:
+        return self._type
+
     def is_message_update(self):
         """bool:
 			Return ``True`` if Update Type is Message"""
@@ -35,6 +44,9 @@ class UpdateType:
 			Return ``True`` if Update Type is Callback"""
         return self._type == self.CALLBACK
 
+    def __repr__(self):
+        return f"<UpdateType type={self.type}>"
+
     def __eq__(self, other):
         return self._type == other
 
