@@ -23,7 +23,7 @@
 import asyncio
 from typing import TYPE_CHECKING
 if TYPE_CHECKING:
-	from bale import Bot
+	from bale import Bot, Update
 
 __all__ = (
 	"Updater",
@@ -53,7 +53,6 @@ class Updater:
     """
 	__slots__ = (
 		"bot",
-		"update_queue",
 		"_last_offset",
 		"_is_running",
 		"sleep_after_get_updates"
@@ -61,7 +60,6 @@ class Updater:
 
 	def __init__(self, bot: "Bot"):
 		self.bot = bot
-		self.update_queue = asyncio.Queue()
 		self._last_offset = None
 		self._is_running = False
 		self.sleep_after_get_updates = None
@@ -74,9 +72,9 @@ class Updater:
 			self.sleep_after_get_updates = sleep_after_every_get_updates
 		self._is_running = True
 		self.bot.dispatch("ready")
-		await self.poll_event()
+		await self._start()
 
-	async def poll_event(self):
+	async def _start(self):
 		"""A loop for get updates in dispatch"""
 		if not self._is_running:
 			raise RuntimeError("Updater is running")
@@ -93,22 +91,24 @@ class Updater:
 			updates = await self.bot.get_updates(offset=self._last_offset)
 
 			for update in updates:
-				self.bot.dispatch("update", update)
-				if update.type == "callback_query":
-					self.bot.dispatch("callback", update.callback_query)
-				elif update.type == "message":
-					self.bot.dispatch("message", update.message)
-
-					if update.message.left_chat_member:
-						self.bot.dispatch("member_chat_leave", update.message.chat, update.message.left_chat_member)
-					for user in update.message.new_chat_members or []:
-						self.bot.dispatch("member_chat_join", update.message.chat, user)
+				await self.call_to_dispatch(update)
 
 			self._last_offset = updates[-1].update_id if bool(updates) else self._last_offset
 
 			if self.sleep_after_get_updates is not None:
 				await asyncio.sleep(self.sleep_after_get_updates)
 
+	async def call_to_dispatch(self, update: "Update"):
+		self.bot.dispatch("update", update)
+		if update.type.is_callback_update():
+			self.bot.dispatch("callback", update.callback_query)
+		elif update.type.is_message_update():
+			self.bot.dispatch("message", update.message)
+			if update.message.left_chat_member:
+				self.bot.dispatch("member_chat_leave", update.message.chat, update.message.left_chat_member)
+			for user in update.message.new_chat_members or []:
+				self.bot.dispatch("member_chat_join", update.message.chat, user)
+
 	def stop(self):
 		"""Stop running and Stop `poll_event` loop"""
 		if not self._is_running:
