@@ -46,7 +46,8 @@ class User:
         "bot"
     )
 
-    def __init__(self, user_id: int, first_name: str, last_name: str = None, username: str = None, bot: 'Bot' = None):
+    def __init__(self, user_id: int, first_name: str, last_name: str = None, username: str = None,
+            bot: 'Bot' = None):
         self.first_name = first_name
         self.last_name = last_name
         self.username = username
@@ -77,7 +78,6 @@ class User:
         -------
             :class:`bale.Message`
                 On success, the sent Message is returned.
-                
         Raises
         ------
             NotFound
@@ -89,7 +89,8 @@ class User:
         """
         return await self.bot.send_message(self, text, components=components)
 
-    async def send_document(self, document: bytes | str | "Document", *, caption: Optional[str] = None):
+    async def send_document(self, document: bytes | str | "Document", *,
+            caption: Optional[str] = None):
         """For the documentation of the arguments, please see :meth:`bale.Bot.send_document`.
 
         Parameters
@@ -126,7 +127,6 @@ class User:
         -------
             :class:`bale.Message`
                 On success, the sent Message is returned.
-        
         Raises
         ------
             NotFound
@@ -138,7 +138,9 @@ class User:
         """
         return await self.bot.send_photo(self, photo, caption=caption)
 
-    async def send_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *, photo_url: Optional[str] = None, need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False, need_email: Optional[bool] = False, need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
+    async def send_invoice(self, title: str, description: str, provider_token: str, prices: List["Price"], *, photo_url: Optional[str] = None,
+               need_name: Optional[bool] = False, need_phone_number: Optional[bool] = False, need_email: Optional[bool] = False,
+               need_shipping_address: Optional[bool] = False, is_flexible: Optional[bool] = True):
         """
         For the documentation of the arguments, please see :meth:`bale.Bot.send_invoice`
 
@@ -172,7 +174,6 @@ class User:
         -------
             :class:`Bale.Message`:
                 On success, the message sent returned.
-                
         Raises
         ------
             NotFound
